class EclParsingError(ValueError):
    """
    Indicates an error occurred during reading of an ecl file.
    """

    pass


class EclWriteError(ValueError):
    """
    Indicates an error occurred during writing of an ecl file.
    """

    pass
